###########################################################################
#
# win32 makefile -- src/oaiserver
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999-2008  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDL_DIR = ..\..\..
COMMON_DIR = $(GSDL_DIR)\common-src
RUNTIME_DIR = $(GSDL_DIR)\runtime-src

INDEXERS_DIR = $(COMMON_DIR)\indexers
COMMON_PACKAGES = $(COMMON_DIR)\packages

PACKAGES_DIR = $(RUNTIME_DIR)\packages
COLSERVR_DIR = $(RUNTIME_DIR)\src\colservr
PROTOCOL_DIR = $(RUNTIME_DIR)\src\protocol
RECPT_DIR    = $(RUNTIME_DIR)\src\recpt


GSDL_VC4 = 0
LOCAL_LIBRARY = 0
DLL = 0
DLLDEBUG = 0
ENABLE_ACCENTFOLD = 1
USE_SQLITE = 0


!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

!IF $(DLL)
CPPFLAGS = $(CPPFLAGS) -MD
!ELSE
!IF ($(DLLDEBUG))
CPPFLAGS = $(CPPFLAGS) -MDd
!ENDIF
!ENDIF

!IF $(ENABLE_ACCENTFOLD)
ACCENTFOLD_LIBS = "$(INDEXERS_DIR)\packages\unac\libunac.lib" "$(INDEXERS_DIR)\packages\windows\iconv\iconv\lib\iconv.lib"
!ELSE
ACCENTFOLD_LIBS = 
!ENDIF

!IF $(USE_SQLITE)
SQLITE_LIBS = "$(COMMON_PACKAGES)\sqlite\lib\sqlite3.lib"
!ELSE
SQLITE_LIBS = 
!ENDIF


AR = lib
CC = cl
DEFS = -D__WIN32__ -DHAVE_CONFIG_H -DPARADOCNUM -D_LITTLE_ENDIAN -DSHORT_SUFFIX -D_CRT_SECURE_NO_DEPRECATE \
        -DGSDL_NOCACHE
INCLUDES = -I"$(COMMON_DIR)\src\lib" -I"$(COLSERVR_DIR)" -I"$(PROTOCOL_DIR)" -I"$(RECPT_DIR)" \
        -I"$(INDEXERS_DIR)\mgpp\text" -I"$(COMMON_PACKAGES)\windows\crypt\crypt" \
	-I"$(COMMON_PACKAGES)\windows\expat\expat" -I"$(COMMON_PACKAGES)\windows\gdbm\gdbm"
LDFLAGS = 
LIBS = "$(COMMON_PACKAGES)\windows\crypt\crypt\crypt.lib" "$(COMMON_PACKAGES)\windows\expat\expat\libexpat.lib" \
        "$(COMMON_PACKAGES)\windows\gdbm\gdbm\gdbm.lib" $(ACCENTFOLD_LIBS) $(SQLITE_LIBS)

!IF $(GSDL_VC4)
DEFS = $(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I"$(COMMON_PACKAGES)\windows\stlport\stlport"
!ENDIF
!IF $(LOCAL_LIBRARY)
DEFS = $(DEFS) -DGSDL_LOCAL_LIBRARY
!ENDIF


COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)
LINK = $(CC) -nologo -Fe"$@" 


.SUFFIXES:
.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 


RECPT_OBJECTS = \
	"$(RECPT_DIR)\cgiargs.obj" \
	"$(RECPT_DIR)\cgiutils.obj" \
	"$(RECPT_DIR)\htmlutils.obj"

SOURCES = \
	abstractlistaction.cpp \
	dublincore.cpp \
	identifyaction.cpp \
	listidsaction.cpp \
	listrecsaction.cpp \
	listsetsaction.cpp \
	metaformat.cpp \
	metaformatsaction.cpp \
	oaiaction.cpp \
	oaiargs.cpp \
	oaiconfig.cpp \
	oaidispatcher.cpp \
	oaimain.cpp \
	oaitools.cpp \
	recordaction.cpp \
	resumptiontoken.cpp \
	rfc1807.cpp

OBJECTS = \
	abstractlistaction.obj \
	dublincore.obj \
	identifyaction.obj \
	listidsaction.obj \
	listrecsaction.obj \
	listsetsaction.obj \
	metaformat.obj \
	metaformatsaction.obj \
	oaiaction.obj \
	oaiargs.obj \
	oaiconfig.obj \
	oaidispatcher.obj \
	oaimain.obj \
	oaitools.obj \
	recordaction.obj \
	resumptiontoken.obj \
	rfc1807.obj

GSDL_LIBS = \
	"$(PROTOCOL_DIR)\gsdlprotocol.lib" \
	"$(COLSERVR_DIR)\gsdlcolservr.lib" \
	"$(INDEXERS_DIR)\mg\src\text\libmgtext.lib" \
	"$(INDEXERS_DIR)\mg\lib\libmglib.lib" \
	"$(INDEXERS_DIR)\mgpp\text\libmgpptext.lib" \
	"$(INDEXERS_DIR)\mgpp\lib\libmgpplib.lib" \
	"$(COMMON_DIR)\src\lib\gsdllib.lib"

EXECUTABLE_OBJECTS = \
	$(OBJECTS) \
	$(RECPT_OBJECTS) \
	$(GSDL_LIBS)

EXECUTABLE = oaiserver.exe


# Default target: make the oaiserver executable
all: $(EXECUTABLE)

oaiserver.exe: $(EXECUTABLE_OBJECTS)
	$(LINK) $(EXECUTABLE_OBJECTS) $(LIBS)

install: $(EXECUTABLE)
	copy $(EXECUTABLE) "$(GSDL_DIR)\cgi-bin"

clean:
	del *.obj
	del $(EXECUTABLE)
