###########################################################################
#
# win32 makefile -- src/w32server
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDL_DIR = ..\..\..
COMMON_DIR = $(GSDL_DIR)\common-src
RUNTIME_DIR = $(GSDL_DIR)\runtime-src

INDEXERS_DIR = $(COMMON_DIR)\indexers
COMMON_PACKAGES = $(COMMON_DIR)\packages

PACKAGES_DIR = $(RUNTIME_DIR)\packages
COLSERVR_DIR = $(RUNTIME_DIR)\src\colservr
PROTOCOL_DIR = $(RUNTIME_DIR)\src\protocol
RECPT_DIR    = $(RUNTIME_DIR)\src\recpt


GSDL_VC4 = 0
ENABLE_ACCENTFOLD = 1
USE_SQLITE = 0


!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

!IF $(ENABLE_ACCENTFOLD)
ACCENTFOLD_LIBS = "$(INDEXERS_DIR)\packages\unac\libunac.lib" "$(INDEXERS_DIR)\packages\windows\iconv\iconv\lib\iconv.lib"
!ELSE
ACCENTFOLD_LIBS = 
!ENDIF

!IF $(USE_SQLITE)
SQLITE_LIBS = "$(COMMON_PACKAGES)\sqlite\lib\sqlite3.lib"
!ELSE
SQLITE_LIBS = 
!ENDIF


AR = lib
CC = cl
DEFS = -D__WIN32__ -DHAVE_CONFIG_H -D_LITTLE_ENDIAN -DPARADOCNUM -DSHORT_SUFFIX -D_CRT_SECURE_NO_DEPRECATE
INCLUDES = -I"$(GSDL_DIR)" -I"$(COMMON_DIR)\src\lib" -I"$(COLSERVR_DIR)" -I"$(PROTOCOL_DIR)" -I"$(RECPT_DIR)" \
	-I"$(COLSERVR_DIR)" -I"$(INDEXERS_DIR)\mg" \
	-I"$(COMMON_PACKAGES)\windows\gdbm\gdbm" \
        -I"$(INDEXERS_DIR)\mg\lib" -I"$(INDEXERS_DIR)\mg\src\text" \
    	-I"$(INDEXERS_DIR)\mgpp\lib" -I"$(INDEXERS_DIR)\mgpp\text"
LDFLAGS =
LIBS = "$(COMMON_PACKAGES)\windows\crypt\crypt\crypt.lib" "$(COMMON_PACKAGES)\windows\expat\expat\libexpat.lib" \
        "$(COMMON_PACKAGES)\windows\gdbm\gdbm\gdbm.lib" $(ACCENTFOLD_LIBS) $(SQLITE_LIBS)
RSC = rc
WINLIBS = kernel32.lib user32.lib gdi32.lib winspool.lib \
          comdlg32.lib advapi32.lib shell32.lib ole32.lib \
          oleaut32.lib uuid.lib odbc32.lib odbccp32.lib 
#wsock32.lib


!IF $(GSDL_VC4)
DEFS = $(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I"$(COMMON_PACKAGES)\windows\stlport\stlport"
!ENDIF


COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)
LINK = $(CC) -nologo $(LDFLAGS) -Fe"$@"


.SUFFIXES:
.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 


SOURCES = \
	cgiwrapper.cpp \
	conftools.cpp \
	d_winsock.cpp \
	fnord.cpp \
	httpreq.cpp \
	httpsend.cpp \
        httpsrv.cpp \
	locate.cpp \
	netio.cpp \
	parse.cpp \
	settings.cpp \
	startbrowser.cpp \
	wincgiutils.cpp

OBJECTS = \
	cgiwrapper.obj \
	conftools.obj \
	d_winsock.obj \
	fnord.obj \
	httpreq.obj \
	httpsend.obj \
        httpsrv.obj \
	locate.obj \
	netio.obj \
	parse.obj \
	settings.obj \
	startbrowser.obj \
	wincgiutils.obj

RESOURCES = \
	server.res

GSDL_LIBS = \
	"$(RECPT_DIR)\gsdlrecpt.lib" \
	"$(PROTOCOL_DIR)\gsdlprotocol.lib" \
	"$(COLSERVR_DIR)\gsdlcolservr.lib" \
	"$(INDEXERS_DIR)\mg\src\text\libmgtext.lib" \
	"$(INDEXERS_DIR)\mg\lib\libmglib.lib" \
	"$(INDEXERS_DIR)\mgpp\text\libmgpptext.lib" \
	"$(INDEXERS_DIR)\mgpp\lib\libmgpplib.lib" \
	"$(COMMON_DIR)\src\lib\gsdllib.lib"

EXECUTABLE_OBJECTS = \
	$(OBJECTS) \
	$(RESOURCES) \
	$(GSDL_LIBS)

EXECUTABLE = server.exe


# Default target: make the local library executable
all: $(EXECUTABLE)

server.exe: $(EXECUTABLE_OBJECTS)
	$(LINK) $(EXECUTABLE_OBJECTS) $(LIBS) $(WINLIBS) 
install:
	copy $(EXECUTABLE) "$(GSDL_DIR)"

clean:
	del *.obj
	del $(EXECUTABLE)


# Resources stuff
SOURCE = "$(RUNTIME_DIR)\src\w32server\newgsdl.bmp"
SOURCE = "$(RUNTIME_DIR)\src\w32server\resource.h"
SOURCE = "$(RUNTIME_DIR)\src\w32server\server.ico"
SOURCE = "$(RUNTIME_DIR)\src\w32server\gsdlcol.bmp"
SOURCE = "$(RUNTIME_DIR)\src\w32server\server.rc"
DEP_RSC_SERVE=\
	"$(RUNTIME_DIR)\src\w32server\gsdlcol.bmp"\
	"$(RUNTIME_DIR)\src\w32server\newgsdl.bmp"\
	"$(RUNTIME_DIR)\src\w32server\server.ico"

server.res : $(SOURCE) $(DEP_RSC_SERVE) "$(RUNTIME_DIR)\src\w32server"
   $(RSC) /l 0x409 /fo"$(RUNTIME_DIR)\src\w32server\server.res" /i "$(RUNTIME_DIR)\src\w32server" \
 /i "$(VCINSTALLDIR)/include/mfc" /d "NDEBUG" $(SOURCE)

"$(RUNTIME_DIR)\src\w32server\server.res" : $(SOURCE) $(DEP_RSC_SERVE) "$(RUNTIME_DIR)\src\w32server"
   $(RSC) /l 0x409 /fo"$(RUNTIME_DIR)\src\w32server\server.res" /i "$(RUNTIME_DIR)\src\w32server" \
 /d "NDEBUG" $(SOURCE)
