###########################################################################
#
# win32 makefile -- src/z3950
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999-2008  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDL_DIR = ..\..\..
COMMON_DIR = $(GSDL_DIR)\common-src
RUNTIME_DIR = $(GSDL_DIR)\runtime-src

INDEXERS_DIR = $(COMMON_DIR)\indexers
PACKAGES_DIR = $(RUNTIME_DIR)\packages
COLSERVR_DIR = $(RUNTIME_DIR)\src\colservr
PROTOCOL_DIR = $(RUNTIME_DIR)\src\protocol


GSDL_VC4 = 0
DLL = 0
DLLDEBUG = 0
ENABLE_ACCENTFOLD = 1
USE_SQLITE = 0


!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

!IF $(DLL)
CPPFLAGS = $(CPPFLAGS) -MD
!ELSE
!IF ($(DLLDEBUG))
CPPFLAGS = $(CPPFLAGS) -MDd
!ENDIF
!ENDIF

!IF $(ENABLE_ACCENTFOLD)
ACCENTFOLD_LIBS = "$(INDEXERS_DIR)\packages\unac\libunac.lib" "$(INDEXERS_DIR)\packages\windows\iconv\iconv\lib\iconv.lib"
!ELSE
ACCENTFOLD_LIBS = 
!ENDIF

!IF $(USE_SQLITE)
SQLITE_LIBS = "$(PACKAGES_DIR)\sqlite\lib\sqlite3.lib"
!ELSE
SQLITE_LIBS = 
!ENDIF


AR = lib
CC = cl
DEFS = -D__WIN32__ -DHAVE_CONFIG_H -DPARADOCNUM -D_LITTLE_ENDIAN -DSHORT_SUFFIX -D_CRT_SECURE_NO_DEPRECATE
# Do NOT add the "recpt" directory here: the z39.50 code should be independent of the receptionist!
INCLUDES = -I"$(GSDL_DIR)" -I"$(COMMON_DIR)\src\lib" -I"$(COLSERVR_DIR)" -I"$(PROTOCOL_DIR)" \
	-I"$(INDEXERS_DIR)\mgpp\text" -I"$(PACKAGES_DIR)\yaz\yaz-2.1.4\include" \
	-I"$(PACKAGES_DIR)\yaz\yaz-2.1.4\client" -I"$(PACKAGES_DIR)\d2m" \
	-I"$(PACKAGES_DIR)\windows\gdbm\gdbm"
LDFLAGS = 
LIBS = "$(PACKAGES_DIR)\windows\expat\expat\libexpat.lib" "$(PACKAGES_DIR)\windows\gdbm\gdbm\gdbm.lib" \
        "$(PACKAGES_DIR)\d2m\libd2m.lib" "$(PACKAGES_DIR)\yaz\yaz-2.1.4\lib\yaz.lib" $(ACCENTFOLD_LIBS) \
	$(SQLITE_LIBS)

!IF $(GSDL_VC4)
DEFS=$(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I"$(PACKAGES_DIR)\windows\stlport\stlport"
!ENDIF


COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)
LINK = $(CC) -nologo -Fe"$@" $(LDFLAGS)


.SUFFIXES:
.SUFFIXES: .c .obj
.c.obj:
	$(COMPILE) $<

.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 


LIBRARY_SOURCES = \
	yaz_zclient.c \
	z3950proto.cpp \
	z3950proxy.cpp \
	zparse.tab.c \
	zparse.yy.c

LIBRARY_OBJECTS = \
	yaz_zclient.obj \
	z3950proto.obj \
	z3950proxy.obj \
	zparse.tab.obj \
	zparse.yy.obj

LIBRARY = gsdlz3950.lib


SOURCES = \
	z3950explain.cpp \
	z3950parser.cpp \
	z3950server.cpp \
	z3950_to_gsdl.cpp

OBJECTS = \
	z3950explain.obj \
	z3950parser.obj \
	z3950server.obj \
	z3950_to_gsdl.obj

GSDL_LIBS = \
	gsdlz3950.lib \
	$(PROTOCOL_DIR)\gsdlprotocol.lib \
	$(COLSERVR_DIR)\gsdlcolservr.lib \
	$(INDEXERS_DIR)\mg/src/text/libmgtext.lib \
	$(INDEXERS_DIR)\mg/lib/libmglib.lib \
	$(INDEXERS_DIR)\mgpp/text/libmgpptext.lib \
	$(INDEXERS_DIR)\mgpp/lib/libmgpplib.lib \
	$(COMMON_DIR)\src\lib\gsdllib.lib

EXECUTABLE_OBJECTS = \
	$(OBJECTS) \
	$(GSDL_LIBS)

EXECUTABLE = z3950server.exe


# Default target: make both gsdlz3950.lib and z3950server.exe
all: $(LIBRARY) $(EXECUTABLE)

gsdlz3950.lib: $(LIBRARY_OBJECTS)
	if EXIST $(LIBRARY) del $(LIBRARY)
	$(AR) -nologo /out:$(LIBRARY) $(LIBRARY_OBJECTS) $(PACKAGES_DIR)/yaz/yaz-2.1.4/win/obj/tabcomplete.obj

z3950server.exe: $(EXECUTABLE_OBJECTS)
	$(LINK) $(EXECUTABLE_OBJECTS) $(LIBS)

install: $(EXECUTABLE)
	copy $(EXECUTABLE) "$(GSDL_DIR)\bin\windows"

clean:
	del *.obj
	del $(LIBRARY)
	del $(EXECUTABLE)
